@@ -19,19 +19,19 @@ has handler => (
 
 has context_class => (
     is => 'rw',
-    isa => 'Str',
+    isa => 'ClassName',
     default => 'HTTP::Engine::Context',
 );
 
 has request_class => (
     is => 'rw',
-    isa => 'Str',
+    isa => 'ClassName',
     default => 'HTTP::Engine::Request',
 );
 
 has response_class => (
     is => 'rw',
-    isa => 'Str',
+    isa => 'ClassName',
     default => 'HTTP::Engine::Response',
 );
 
@@ -67,7 +67,15 @@ sub handle_request {
         res    => $self->response_class->new(),
     );
 
-    $self->request_builder->prepare($context);
+    eval {
+        $self->request_builder->prepare($context);
+    };
+    if (my $e = $@) {
+        print STDERR $e;
+
+        $context->res->status(500);
+        $context->res->body('internal server error');
+    }
 
     my $ret = eval {
         local *STDOUT;
